<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=hac
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// I
	'icone_mots_cles' => 'واژه-كليدها',
	'info_retirer_mot' => 'اين واژه را برداريد',
	'info_retirer_mots' => 'تمام واژه ها را برداريد'
);

?>
